==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/bean/RecoveryApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * 恢复申请详情
 *
 * @author yangmenghao
 * @date 2020-01-13 13:23:02
 */
public class RecoveryApplyInfo {
    /**
     * 申请原因-必须
     */
    private String applyReason;
    /**
     * 申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销-必须
     */
    private Integer applyStatus;
    /**
     * 待撤销证书DN-必须
     */
    private String certDn;
    /**
     * 证书有效期-必须
     */
    private Integer certValidity;
    /**
     * 待撤销证书的加密证书SN-必须
     */
    private String encSn;
    /**
     * 必须	申请创建时间
     */
    private String gmtCreate;
    /**
     * 密钥长度-必须
     */
    private Integer privateKeyLength;
    /**
     * 证书签名算法-必须
     */
    private String signAlg;
    /**
     * 签名证书SN-必须
     */
    private String signSn;
    /**
     * 模板名称-必须
     */
    private String tempName;
    /**
     * 模板编号-必须
     */
    private String tempNo;
    /**
     * 模板要求参数-必须
     */
    private String tempParas;

    public RecoveryApplyInfo() {
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("RecoveryApplyInfo{");
        sb.append("applyReason='").append(applyReason).append('\'');
        sb.append(", applyStatus=").append(applyStatus);
        sb.append(", certDn='").append(certDn).append('\'');
        sb.append(", certValidity=").append(certValidity);
        sb.append(", encSn='").append(encSn).append('\'');
        sb.append(", gmtCreate='").append(gmtCreate).append('\'');
        sb.append(", privateKeyLength=").append(privateKeyLength);
        sb.append(", signAlg='").append(signAlg).append('\'');
        sb.append(", signSn='").append(signSn).append('\'');
        sb.append(", tempName='").append(tempName).append('\'');
        sb.append(", tempNo='").append(tempNo).append('\'');
        sb.append(", tempParas='").append(tempParas).append('\'');
        sb.append('}');
        return sb.toString();
    }
}

==> ra-sdk-2.0.0-sources.jar: com/xdja/ra/bean/RecoveryApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * 恢复申请详情
 *
 * @author yangmenghao
 * @date 2020-01-13 13:23:02
 */
public class RecoveryApplyInfo {
    /**
     * 申请原因-必须
     */
    private String applyReason;
    /**
     * 申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销-必须
     */
    private Integer applyStatus;
    /**
     * 待撤销证书DN-必须
     */
    private String certDn;
    /**
     * 证书有效期-必须
     */
    private Integer certValidity;
    /**
     * 待撤销证书的加密证书SN-必须
     */
    private String encSn;
    /**
     * 必须	申请创建时间
     */
    private String gmtCreate;
    /**
     * 密钥长度-必须
     */
    private Integer privateKeyLength;
    /**
     * 证书签名算法-必须
     */
    private String signAlg;
    /**
     * 签名证书SN-必须
     */
    private String signSn;
    /**
     * 模板名称-必须
     */
    private String tempName;
    /**
     * 模板编号-必须
     */
    private String tempNo;
    /**
     * 模板要求参数-必须
     */
    private String tempParas;
    /**
     * 所属用户CA
     */
    private String userCA;

    public String getUserCA() {
        return userCA;
    }

    public void setUserCA(String userCA) {
        this.userCA = userCA;
    }

    public RecoveryApplyInfo() {
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("RecoveryApplyInfo{");
        sb.append("applyReason='").append(applyReason).append('\'');
        sb.append(", applyStatus=").append(applyStatus);
        sb.append(", certDn='").append(certDn).append('\'');
        sb.append(", certValidity=").append(certValidity);
        sb.append(", encSn='").append(encSn).append('\'');
        sb.append(", gmtCreate='").append(gmtCreate).append('\'');
        sb.append(", privateKeyLength=").append(privateKeyLength);
        sb.append(", signAlg='").append(signAlg).append('\'');
        sb.append(", signSn='").append(signSn).append('\'');
        sb.append(", tempName='").append(tempName).append('\'');
        sb.append(", tempNo='").append(tempNo).append('\'');
        sb.append(", tempParas='").append(tempParas).append('\'');
        sb.append(", userCA='").append(userCA).append('\'');
        sb.append('}');
        return sb.toString();
    }
}
